==> ZenTaoALM.12.4.2.int.zbox_old.64.tar.gz: zbox/app/zentaoep/module/feedback/lang/zh-tw.php <==
<?php
$lang->feedback->common       = '反饋';
$lang->feedback->module       = '所屬分類';
$lang->feedback->moduleAB     = '分類';
$lang->feedback->manageCate   = '維護分類';
$lang->feedback->index        = '反饋首頁';
$lang->feedback->create       = '創建反饋';
$lang->feedback->edit         = '編輯反饋';
$lang->feedback->createFaq    = '創建FAQ';
$lang->feedback->faq          = 'FAQ';
$lang->feedback->nonRDBrowse  = '非研發界面瀏覽';
$lang->feedback->browse       = '瀏覽反饋';
$lang->feedback->list         = '反饋列表';
$lang->feedback->header       = '問題反饋';
$lang->feedback->view         = '反饋詳情';
$lang->feedback->review       = '評審';
$lang->feedback->reviewAction = '評審反饋';
$lang->feedback->adminView    = '研發頁面反饋詳情';
$lang->feedback->close        = '關閉';
$lang->feedback->closeAction  = '關閉反饋';
$lang->feedback->feelLike     = '等感覺很贊！';
$lang->feedback->ask          = '追問';
$lang->feedback->toStory      = '轉' . $lang->storyCommon;
$lang->feedback->toTask       = '轉任務';
$lang->feedback->toBug        = '轉Bug';
$lang->feedback->toTodo       = '轉待辦';
$lang->feedback->story        = $lang->storyCommon . '信息';
$lang->feedback->bug          = 'Bug信息';
$lang->feedback->todo         = '待辦信息';
$lang->feedback->task         = '任務信息';
$lang->feedback->reply        = '回覆';
$lang->feedback->replyAction  = '回覆反饋';
$lang->feedback->convert      = '轉化';
$lang->feedback->assign       = '指派';
$lang->feedback->assignAction = '指派反饋';
$lang->feedback->export       = '導出';
$lang->feedback->exportAction = '導出反饋';
$lang->feedback->assignTo     = '指派';
$lang->feedback->mailto       = '抄送給';
$lang->feedback->delete       = '刪除反饋';
$lang->feedback->mailNotify   = '接收郵件通知。';
$lang->feedback->search       = '搜索';
$lang->feedback->comment      = '評論';
$lang->feedback->products     = '權限';
$lang->feedback->batchEdit    = '批量編輯';
$lang->feedback->batchClose   = '批量關閉';
$lang->feedback->batchReview       = '批量評審';
$lang->feedback->batchAssignTo     = '批量指派';
$lang->feedback->batchChangeModule = '批量更改模組';
$lang->feedback->manageProduct     = '授權用戶';

$lang->feedback->id             = '編號';
$lang->feedback->product        = '所屬產品';
$lang->feedback->title          = '標題';
$lang->feedback->desc           = '描述';
$lang->feedback->status         = '狀態';
$lang->feedback->subStatus      = '子狀態';
$lang->feedback->openedBy       = '反饋人';
$lang->feedback->openedDate     = '反饋時間';
$lang->feedback->processedBy    = '由誰處理';
$lang->feedback->processedDate  = '處理時間';
$lang->feedback->reviewedBy     = '由誰評審';
$lang->feedback->reviewedDate   = '評審時間';
$lang->feedback->reviewResult   = '評審結果';
$lang->feedback->reviewedByAB   = '評審人';
$lang->feedback->reviewedDateAB = '日期';
$lang->feedback->reviewResultAB = '結果';
$lang->feedback->assignedTo     = '指派給';
$lang->feedback->assignedDate   = '指派時間';
$lang->feedback->closedBy       = '由誰關閉';
$lang->feedback->closedDate     = '關閉時間';
$lang->feedback->closedReason   = '關閉原因';
$lang->feedback->public         = '公開';
$lang->feedback->notify         = '通知';
$lang->feedback->likes          = '點贊人';
$lang->feedback->result         = '轉化結果';
$lang->feedback->files          = '附件';
$lang->feedback->labelBasic     = '基本信息';
$lang->feedback->dept           = '部門';
$lang->feedback->editedBy       = '最後處理人';
$lang->feedback->editedDate     = '最後修改時間';
$lang->feedback->contactInfo    = '聯繫方式';
$lang->feedback->noAssigned     = '未指派';
$lang->feedback->deptManager    = '部門負責人';
$lang->feedback->reviewOpinion  = '評審意見';
$lang->feedback->deleted        = '已刪除';

$lang->feedback->lblBasic   = '基本信息';
$lang->feedback->lblTrace   = '追溯關係圖';
$lang->feedback->assigntome = '指派給我';
$lang->feedback->allProduct = '所有' . $lang->productCommon;

$lang->feedback->grantUser   = '授權用戶';
$lang->feedback->noGrantUser = '非授權用戶';
$lang->feedback->hasPrivUser = '註：可以創建反饋的用戶預設有所有產品的權限，被分配權限後只有對應的產品權限。';

$lang->feedback->tabList['unclosed'] = '未關閉';
$lang->feedback->tabList['all']      = '全部';
$lang->feedback->tabList['public']   = '公開';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = '確認通過';
$lang->feedback->reviewResultList['clarify'] = '繼續完善';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = '待評審';
$lang->feedback->statusList['clarify']    = '待完善';
$lang->feedback->statusList['wait']       = '待處理';
$lang->feedback->statusList['commenting'] = '處理中';
$lang->feedback->statusList['replied']    = '已處理';
$lang->feedback->statusList['asked']      = '追問中';
$lang->feedback->statusList['tobug']      = '轉Bug';
$lang->feedback->statusList['tostory']    = '轉' . $lang->storyCommon;
$lang->feedback->statusList['totask']     = '轉任務';
$lang->feedback->statusList['totodo']     = '轉待辦';
$lang->feedback->statusList['closed']     = '已關閉';

$lang->feedback->closedReasonList[]            = '';
$lang->feedback->closedReasonList['commented'] = '已處理';
$lang->feedback->closedReasonList['tobug']     = '轉Bug';
$lang->feedback->closedReasonList['tostory']   = '轉' . $lang->storyCommon;
$lang->feedback->closedReasonList['totask']    = '轉任務';
$lang->feedback->closedReasonList['totodo']    = '轉待辦';
$lang->feedback->closedReasonList['repeat']    = '重複';
$lang->feedback->closedReasonList['refuse']    = '不予採納';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = '不公開';
$lang->feedback->publicList['1'] = '公開';

$lang->feedback->confirmDelete = '是否刪除該反饋？';
$lang->feedback->confirmClose  = '是否關閉該反饋？';

$lang->feedback->commented        = '$date, 由 <strong>$actor</strong> 添加評論。' . "\n";
$lang->feedback->noModule         = '<div>您現在還沒有分類信息</div>';
$lang->feedback->mustChooseResult = '必須選擇評審結果';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, 由 <strong>$actor</strong> 關閉，原因為 <strong>$extra</strong>。', 'extra' => 'closedReasonList');   
$lang->feedback->action->reviewed = array('main' => '$date, 由 <strong>$actor</strong> 記錄評審結果，結果為 <strong>$extra</strong>。', 'extra' => 'reviewResultList');

==> ZenTaoALM.12.4.4.int.zbox_old.64.tar.gz: zbox/app/zentaoep/module/feedback/lang/zh-tw.php <==
<?php
$lang->feedback->common       = '反饋';
$lang->feedback->module       = '所屬分類';
$lang->feedback->moduleAB     = '分類';
$lang->feedback->manageCate   = '維護分類';
$lang->feedback->index        = '反饋首頁';
$lang->feedback->create       = '創建反饋';
$lang->feedback->edit         = '編輯反饋';
$lang->feedback->createFaq    = '創建FAQ';
$lang->feedback->faq          = 'FAQ';
$lang->feedback->nonRDBrowse  = '非研發界面瀏覽';
$lang->feedback->browse       = '瀏覽反饋';
$lang->feedback->list         = '反饋列表';
$lang->feedback->header       = '問題反饋';
$lang->feedback->view         = '反饋詳情';
$lang->feedback->review       = '評審';
$lang->feedback->reviewAction = '評審反饋';
$lang->feedback->adminView    = '研發頁面反饋詳情';
$lang->feedback->close        = '關閉';
$lang->feedback->closeAction  = '關閉反饋';
$lang->feedback->feelLike     = '等感覺很贊！';
$lang->feedback->ask          = '追問';
$lang->feedback->toStory      = '轉' . $lang->storyCommon;
$lang->feedback->toTask       = '轉任務';
$lang->feedback->toBug        = '轉Bug';
$lang->feedback->toTodo       = '轉待辦';
$lang->feedback->story        = $lang->storyCommon . '信息';
$lang->feedback->bug          = 'Bug信息';
$lang->feedback->todo         = '待辦信息';
$lang->feedback->task         = '任務信息';
$lang->feedback->reply        = '回覆';
$lang->feedback->replyAction  = '回覆反饋';
$lang->feedback->convert      = '轉化';
$lang->feedback->assign       = '指派';
$lang->feedback->assignAction = '指派反饋';
$lang->feedback->export       = '導出';
$lang->feedback->exportAction = '導出反饋';
$lang->feedback->assignTo     = '指派';
$lang->feedback->mailto       = '抄送給';
$lang->feedback->delete       = '刪除反饋';
$lang->feedback->mailNotify   = '接收郵件通知。';
$lang->feedback->search       = '搜索';
$lang->feedback->comment      = '評論';
$lang->feedback->products     = '權限';
$lang->feedback->batchEdit    = '批量編輯';
$lang->feedback->batchClose   = '批量關閉';
$lang->feedback->batchReview       = '批量評審';
$lang->feedback->batchAssignTo     = '批量指派';
$lang->feedback->batchChangeModule = '批量更改模組';
$lang->feedback->manageProduct     = '授權用戶';

$lang->feedback->id             = '編號';
$lang->feedback->product        = '所屬' . $lang->productCommon;
$lang->feedback->title          = '標題';
$lang->feedback->desc           = '描述';
$lang->feedback->status         = '狀態';
$lang->feedback->subStatus      = '子狀態';
$lang->feedback->openedBy       = '反饋人';
$lang->feedback->openedDate     = '反饋時間';
$lang->feedback->processedBy    = '由誰處理';
$lang->feedback->processedDate  = '處理時間';
$lang->feedback->reviewedBy     = '由誰評審';
$lang->feedback->reviewedDate   = '評審時間';
$lang->feedback->reviewResult   = '評審結果';
$lang->feedback->reviewedByAB   = '評審人';
$lang->feedback->reviewedDateAB = '日期';
$lang->feedback->reviewResultAB = '結果';
$lang->feedback->assignedTo     = '指派給';
$lang->feedback->assignedDate   = '指派時間';
$lang->feedback->closedBy       = '由誰關閉';
$lang->feedback->closedDate     = '關閉時間';
$lang->feedback->closedReason   = '關閉原因';
$lang->feedback->public         = '公開';
$lang->feedback->notify         = '通知';
$lang->feedback->likes          = '點贊人';
$lang->feedback->result         = '轉化結果';
$lang->feedback->files          = '附件';
$lang->feedback->labelBasic     = '基本信息';
$lang->feedback->dept           = '部門';
$lang->feedback->editedBy       = '最後處理人';
$lang->feedback->editedDate     = '最後修改時間';
$lang->feedback->contactInfo    = '聯繫方式';
$lang->feedback->noAssigned     = '未指派';
$lang->feedback->deptManager    = '部門負責人';
$lang->feedback->reviewOpinion  = '評審意見';
$lang->feedback->deleted        = '已刪除';

$lang->feedback->lblBasic   = '基本信息';
$lang->feedback->lblTrace   = '追溯關係圖';
$lang->feedback->assigntome = '指派給我';
$lang->feedback->allProduct = '所有' . $lang->productCommon;

$lang->feedback->grantUser   = '授權用戶';
$lang->feedback->noGrantUser = '非授權用戶';
$lang->feedback->hasPrivUser = '註：可以創建反饋的用戶預設有所有產品的權限，被分配權限後只有對應的產品權限。';

$lang->feedback->tabList['unclosed'] = '未關閉';
$lang->feedback->tabList['all']      = '全部';
$lang->feedback->tabList['public']   = '公開';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = '確認通過';
$lang->feedback->reviewResultList['clarify'] = '繼續完善';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = '待評審';
$lang->feedback->statusList['clarify']    = '待完善';
$lang->feedback->statusList['wait']       = '待處理';
$lang->feedback->statusList['commenting'] = '處理中';
$lang->feedback->statusList['replied']    = '已處理';
$lang->feedback->statusList['asked']      = '追問中';
$lang->feedback->statusList['tobug']      = '轉Bug';
$lang->feedback->statusList['tostory']    = '轉' . $lang->storyCommon;
$lang->feedback->statusList['totask']     = '轉任務';
$lang->feedback->statusList['totodo']     = '轉待辦';
$lang->feedback->statusList['closed']     = '已關閉';

$lang->feedback->closedReasonList[]            = '';
$lang->feedback->closedReasonList['commented'] = '已處理';
$lang->feedback->closedReasonList['tobug']     = '轉Bug';
$lang->feedback->closedReasonList['tostory']   = '轉' . $lang->storyCommon;
$lang->feedback->closedReasonList['totask']    = '轉任務';
$lang->feedback->closedReasonList['totodo']    = '轉待辦';
$lang->feedback->closedReasonList['repeat']    = '重複';
$lang->feedback->closedReasonList['refuse']    = '不予採納';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = '不公開';
$lang->feedback->publicList['1'] = '公開';

$lang->feedback->confirmDelete = '是否刪除該反饋？';
$lang->feedback->confirmClose  = '是否關閉該反饋？';

$lang->feedback->commented        = '$date, 由 <strong>$actor</strong> 添加評論。' . "\n";
$lang->feedback->noModule         = '<div>您現在還沒有分類信息</div>';
$lang->feedback->mustChooseResult = '必須選擇評審結果';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, 由 <strong>$actor</strong> 關閉，原因為 <strong>$extra</strong>。', 'extra' => 'closedReasonList');   
$lang->feedback->action->reviewed = array('main' => '$date, 由 <strong>$actor</strong> 記錄評審結果，結果為 <strong>$extra</strong>。', 'extra' => 'reviewResultList');
